@@ -5,6 +5,10 @@
            , TupleSections
   #-}
 
+#if __GLASGOW_HASKELL__ >= 702
+{-# LANGUAGE Trustworthy #-}
+#endif
+
 {- |
 Module      :  Control.Concurrent.MVar.Lifted
 Copyright   :  Bas van Dijk
@@ -13,8 +17,8 @@ License     :  BSD-style
 Maintainer  :  Bas van Dijk <v.dijk.bas@gmail.com>
 Stability   :  experimental
 
-This is a wrapped version of 'Control.Concurrent.MVar' with types generalized
-from @IO@ to all monads in either 'MonadBase' or 'MonadBaseControl'.
+This is a wrapped version of "Control.Concurrent.MVar" with types generalized
+from 'IO' to all monads in either 'MonadBase' or 'MonadBaseControl'.
 -}
 
 module Control.Concurrent.MVar.Lifted
@@ -81,62 +85,62 @@ import Control.Monad.Trans.Control ( MonadBaseControl
 --------------------------------------------------------------------------------
 
 -- | Generalized version of 'MVar.newEmptyMVar'.
-newEmptyMVar ∷ MonadBase IO m ⇒ m (MVar α)
+newEmptyMVar ∷ MonadBase IO m ⇒ m (MVar a)
 newEmptyMVar = liftBase MVar.newEmptyMVar
 {-# INLINABLE newEmptyMVar #-}
 
 -- | Generalized version of 'MVar.newMVar'.
-newMVar ∷ MonadBase IO m ⇒ α → m (MVar α)
+newMVar ∷ MonadBase IO m ⇒ a → m (MVar a)
 newMVar = liftBase ∘ MVar.newMVar
 {-# INLINABLE newMVar #-}
 
 -- | Generalized version of 'MVar.takeMVar'.
-takeMVar ∷ MonadBase IO m ⇒ MVar α → m α
+takeMVar ∷ MonadBase IO m ⇒ MVar a → m a
 takeMVar = liftBase ∘ MVar.takeMVar
 {-# INLINABLE takeMVar #-}
 
 -- | Generalized version of 'MVar.putMVar'.
-putMVar ∷ MonadBase IO m ⇒ MVar α → α → m ()
+putMVar ∷ MonadBase IO m ⇒ MVar a → a → m ()
 putMVar mv x = liftBase $ MVar.putMVar mv x
 {-# INLINABLE putMVar #-}
 
 -- | Generalized version of 'MVar.readMVar'.
-readMVar ∷ MonadBase IO m ⇒ MVar α → m α
+readMVar ∷ MonadBase IO m ⇒ MVar a → m a
 readMVar = liftBase ∘ MVar.readMVar
 {-# INLINABLE readMVar #-}
 
 -- | Generalized version of 'MVar.swapMVar'.
-swapMVar ∷ MonadBase IO m ⇒ MVar α → α → m α
+swapMVar ∷ MonadBase IO m ⇒ MVar a → a → m a
 swapMVar mv x = liftBase $ MVar.swapMVar mv x
 {-# INLINABLE swapMVar #-}
 
 -- | Generalized version of 'MVar.tryTakeMVar'.
-tryTakeMVar ∷ MonadBase IO m ⇒ MVar α → m (Maybe α)
+tryTakeMVar ∷ MonadBase IO m ⇒ MVar a → m (Maybe a)
 tryTakeMVar = liftBase ∘ MVar.tryTakeMVar
 {-# INLINABLE tryTakeMVar #-}
 
 -- | Generalized version of 'MVar.tryPutMVar'.
-tryPutMVar ∷ MonadBase IO m ⇒ MVar α → α → m Bool
+tryPutMVar ∷ MonadBase IO m ⇒ MVar a → a → m Bool
 tryPutMVar mv x = liftBase $ MVar.tryPutMVar mv x
 {-# INLINABLE tryPutMVar #-}
 
 -- | Generalized version of 'MVar.isEmptyMVar'.
-isEmptyMVar ∷ MonadBase IO m ⇒ MVar α → m Bool
+isEmptyMVar ∷ MonadBase IO m ⇒ MVar a → m Bool
 isEmptyMVar = liftBase ∘ MVar.isEmptyMVar
 {-# INLINABLE isEmptyMVar #-}
 
 -- | Generalized version of 'MVar.withMVar'.
-withMVar ∷ MonadBaseControl IO m ⇒ MVar α → (α → m β) → m β
+withMVar ∷ MonadBaseControl IO m ⇒ MVar a → (a → m b) → m b
 withMVar = liftBaseOp ∘ MVar.withMVar
 {-# INLINABLE withMVar #-}
 
 -- | Generalized version of 'MVar.modifyMVar_'.
-modifyMVar_ ∷ (MonadBaseControl IO m, MonadBase IO m) ⇒ MVar α → (α → m α) → m ()
+modifyMVar_ ∷ (MonadBaseControl IO m) ⇒ MVar a → (a → m a) → m ()
 modifyMVar_ mv = modifyMVar mv ∘ (fmap (, ()) ∘)
 {-# INLINABLE modifyMVar_ #-}
 
 -- | Generalized version of 'MVar.modifyMVar'.
-modifyMVar ∷ (MonadBaseControl IO m, MonadBase IO m) ⇒ MVar α → (α → m (α, β)) → m β
+modifyMVar ∷ (MonadBaseControl IO m) ⇒ MVar a → (a → m (a, b)) → m b
 
 #if MIN_VERSION_base(4,3,0)
 modifyMVar mv f = control $ \runInIO -> mask $ \restore → do
@@ -173,6 +177,6 @@ modifyMVar mv f = control $ \runInIO -> block $ do
 --
 -- Note any monadic side effects in @m@ of the \"finalizer\" computation are
 -- discarded.
-addMVarFinalizer ∷ MonadBaseControl IO m ⇒ MVar α → m () → m ()
+addMVarFinalizer ∷ MonadBaseControl IO m ⇒ MVar a → m () → m ()
 addMVarFinalizer = liftBaseDiscard ∘ MVar.addMVarFinalizer
 {-# INLINABLE addMVarFinalizer #-}
